@@ -31,6 +31,7 @@ class BaseAdaptorField(object):
         self.config['app_label'] = self.model._meta.app_label
         self.config['module_name'] = self.model._meta.module_name
         self.config['filters_to_show'] = filters_to_show
+        self.config['can_auto_save'] = 1
 
         filters_to_edit = self.config.get('filters_to_edit', None)
         self.filters_to_edit = filters_to_edit and filters_to_edit.split('|') or []
@@ -139,10 +140,14 @@ class BaseAdaptorField(object):
         return self.config.get('auto_width', False)
 
     def treatment_height(self, height, width=None):
-        return "%spx" % height
+        if isinstance(height, basestring) and not height.endswith('px'):
+            height = "%spx" % height
+        return height
 
     def treatment_width(self, width, height=None):
-        return "%spx" % width
+        if isinstance(width, basestring) and not width.endswith('px'):
+            width = "%spx" % width
+        return width
 
     def _adding_size(self, field):
         attrs = field.field.widget.attrs
@@ -211,10 +216,6 @@ class AdaptorTextAreaField(BaseAdaptorField):
     def name(self):
         return 'textarea'
 
-    @property
-    def classes(self):
-        return "textareainplaceedit %s" % super(AdaptorTextAreaField, self).classes
-
 
 class AdaptorBooleanField(BaseAdaptorField):
 
@@ -235,6 +236,10 @@ class AdaptorBooleanField(BaseAdaptorField):
 
 class BaseDateField(BaseAdaptorField):
 
+    def __init__(self, *args, **kwargs):
+        super(BaseDateField, self).__init__(*args, **kwargs)
+        self.config['can_auto_save'] = 0
+
     def render_media_field(self, template_name="inplaceeditform/adaptor_date/render_media_field.html"):
         return super(BaseDateField, self).render_media_field(template_name)
 
@@ -361,6 +366,10 @@ class AdaptorCommaSeparatedManyToManyField(AdaptorManyToManyField):
     def name(self):
         return 'm2mcomma'
 
+    def __init__(self, *args, **kwargs):
+        super(AdaptorCommaSeparatedManyToManyField, self).__init__(*args, **kwargs)
+        self.config['can_auto_save'] = 0
+
     def render_value(self, field_name=None, template_name="inplaceeditform/adaptor_m2m/render_commaseparated_value.html"):
         queryset = super(AdaptorCommaSeparatedManyToManyField, self).render_value(field_name)
         return render_to_string(template_name, {'queryset': queryset})
@@ -372,7 +381,7 @@ class AdaptorFileField(BaseAdaptorField):
 
     def __init__(self, *args, **kwargs):
         super(AdaptorFileField, self).__init__(*args, **kwargs)
-        self.config['send_csrfToken'] = 1
+        self.config['can_auto_save'] = 0
 
     def loads_to_post(self, request):
         files = request.FILES.values()
