@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from django.contrib.auth.decorators import login_required
 from django.contrib.contenttypes.models import ContentType
 from django.http import HttpResponse
 from django.forms import ValidationError
@@ -9,17 +8,18 @@ from django.utils import simplejson
 from inplaceeditform.commons import (get_dict_from_obj, apply_filters,
                                      get_adaptor_class)
 
+MIMETYPE_RESPONSE = 'text'
+
 
-@login_required
 def save_ajax(request):
     if not request.method == 'POST':
-        return HttpResponse(simplejson.dumps({'errors': 'It is not a POST request'}),
-                            mimetype='application/json')
+        return _get_http_response({'errors': 'It is not a POST request'})
     adaptor = _get_adaptor(request, 'POST')
+    if not adaptor.can_edit():
+        return _get_http_response({'errors': 'You can not edit this content'})
     if not adaptor:
-        return HttpResponse(simplejson.dumps({'errors': 'Params insufficient'}),
-                            mimetype='application/json')
-    value = simplejson.loads(request.POST.get('value'))
+        return _get_http_response({'errors': 'Params insufficient'})
+    value = adaptor.loads_to_post(request)
     new_data = get_dict_from_obj(adaptor.obj)
     form_class = adaptor.get_form_class()
     field_name = adaptor.field_name
@@ -31,35 +31,31 @@ def save_ajax(request):
         new_data[field_name] = value_edit_with_filter
         if form.is_valid():
             adaptor.save(value_edit_with_filter)
-            return HttpResponse(simplejson.dumps({'errors': False,
-                                            'value': adaptor.render_value()}),
-                                mimetype='application/json')
+            return _get_http_response({'errors': False,
+                                       'value': adaptor.render_value_edit()})
         messages = []  # The error is for another field that you are editing
         for field_name_error, errors_field in form.errors.items():
             for error in errors_field:
                 messages.append("%s: %s" % (field_name_error, unicode(error)))
         message_i18n = ','.join(messages)
-        return HttpResponse(simplejson.dumps({'errors': message_i18n}), mimetype='application/json')
+        return _get_http_response({'errors': message_i18n})
     except ValidationError, error:  # The error is for a field that you are editing
         message_i18n = ', '.join([u"%s" % m for m in error.messages])
-        return HttpResponse(simplejson.dumps({'errors': message_i18n}), mimetype='application/json')
+        return _get_http_response({'errors': message_i18n})
 
 
-@login_required
 def get_field(request):
     if not request.method == 'GET':
-        return HttpResponse(simplejson.dumps({'errors': 'It is not a GET request'}),
-                            mimetype='application/json')
+        return _get_http_response({'errors': 'It is not a GET request'})
     adaptor = _get_adaptor(request, 'GET')
+    if not adaptor.can_edit():
+        return _get_http_response({'errors': 'You can not edit this content'})
     if not adaptor:
-        return HttpResponse(simplejson.dumps({'errors': 'Params insufficient'}),
-                            mimetype='application/json')
-
+        return _get_http_response({'errors': 'Params insufficient'})
     field_render = adaptor.render_field()
     field_media_render = adaptor.render_media_field()
-    return HttpResponse(simplejson.dumps({'field_render': field_render,
-                                          'field_media_render': field_media_render}),
-                                        mimetype='application/json')
+    return _get_http_response({'field_render': field_render,
+                               'field_media_render': field_media_render})
 
 
 def _get_adaptor(request, method='GET'):
@@ -110,3 +106,8 @@ def _convert_params_in_config(request_params, exclude_params=None):
                 config[str(key)] = value
     config['widget_options'] = options_widget
     return config
+
+
+def _get_http_response(context, mimetype=MIMETYPE_RESPONSE):
+    return HttpResponse(simplejson.dumps(context),
+                        mimetype=MIMETYPE_RESPONSE)
